@@ -22,7 +22,11 @@ try:
     __version__ = get_distribution(__name__).version
 except DistributionNotFound:
    # package is not installed
-   pass
+    try:
+        import setuptools_scm
+        __version__ = setuptools_scm.get_version('../')
+    except (ImportError, LookupError):
+        __version__ = None
 
 
 from pyarrow.lib import cpu_count, set_cpu_count
@@ -33,13 +37,7 @@ from pyarrow.lib import (null, bool_,
                          float16, float32, float64,
                          binary, string, decimal,
                          list_, struct, dictionary, field,
-                         DataType,
-                         DecimalType,
-                         DictionaryType,
-                         FixedSizeBinaryType,
-                         TimestampType,
-                         Time32Type,
-                         Time64Type,
+                         DataType, NAType,
                          Field,
                          Schema,
                          schema,
@@ -59,8 +57,8 @@ from pyarrow.lib import (null, bool_,
                          DictionaryArray,
                          Date32Array, Date64Array,
                          TimestampArray, Time32Array, Time64Array,
-                         DecimalArray,
-                         ArrayValue, Scalar, NA, NAType,
+                         DecimalArray, StructArray,
+                         ArrayValue, Scalar, NA,
                          BooleanValue,
                          Int8Value, Int16Value, Int32Value, Int64Value,
                          UInt8Value, UInt16Value, UInt32Value, UInt64Value,
@@ -70,12 +68,12 @@ from pyarrow.lib import (null, bool_,
                          Date32Value, Date64Value, TimestampValue)
 
 from pyarrow.lib import (HdfsFile, NativeFile, PythonFile,
+                         FixedSizeBufferOutputStream,
                          Buffer, BufferReader, BufferOutputStream,
                          OSFile, MemoryMappedFile, memory_map,
-                         frombuffer, read_tensor, write_tensor,
+                         frombuffer,
                          memory_map, create_memory_map,
-                         get_record_batch_size, get_tensor_size,
-                         have_libhdfs, have_libhdfs3)
+                         have_libhdfs, have_libhdfs3, MockOutputStream)
 
 from pyarrow.lib import (MemoryPool, total_allocated_bytes,
                          set_memory_pool, default_memory_pool)
@@ -90,40 +88,28 @@ from pyarrow.lib import (ArrowException,
                          ArrowTypeError)
 
 
-def jemalloc_memory_pool():
-    """
-    Returns a jemalloc-based memory allocator, which can be passed to
-    pyarrow.set_memory_pool
-    """
-    from pyarrow._jemalloc import default_pool
-    return default_pool()
+from pyarrow.filesystem import FileSystem, LocalFileSystem
 
+from pyarrow.hdfs import HadoopFileSystem
+import pyarrow.hdfs as hdfs
 
-from pyarrow.filesystem import Filesystem, HdfsClient, LocalFilesystem
-
-from pyarrow.ipc import (RecordBatchFileReader, RecordBatchFileWriter,
+from pyarrow.ipc import (Message, MessageReader,
+                         RecordBatchFileReader, RecordBatchFileWriter,
                          RecordBatchStreamReader, RecordBatchStreamWriter,
+                         read_message, read_record_batch, read_tensor,
+                         write_tensor,
+                         get_record_batch_size, get_tensor_size,
                          open_stream,
                          open_file,
                          serialize_pandas, deserialize_pandas)
 
-
-localfs = LocalFilesystem.get_instance()
+localfs = LocalFileSystem.get_instance()
 
 
 # ----------------------------------------------------------------------
 # 0.4.0 deprecations
 
-import warnings
-
-def _deprecate_class(old_name, new_name, klass, next_version='0.5.0'):
-    msg = ('pyarrow.{0} has been renamed to '
-           '{1}, will be removed in {2}'
-           .format(old_name, new_name, next_version))
-    def deprecated_factory(*args, **kwargs):
-        warnings.warn(msg, FutureWarning)
-        return klass(*args)
-    return deprecated_factory
+from pyarrow.util import _deprecate_class
 
 FileReader = _deprecate_class('FileReader',
                               'RecordBatchFileReader',
@@ -144,3 +130,7 @@ StreamWriter = _deprecate_class('StreamWriter',
 InMemoryOutputStream = _deprecate_class('InMemoryOutputStream',
                                         'BufferOutputStream',
                                         BufferOutputStream, '0.5.0')
+
+# Backwards compatibility with pyarrow < 0.6.0
+HdfsClient = _deprecate_class('HdfsClient', 'pyarrow.hdfs.connect',
+                              hdfs.connect, '0.6.0')
